@@ -12,9 +12,13 @@
         <translation type="obsolete">cuteTube-QML - 0.3.10 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="36"/>
         <source>cuteTube-QML - 0.4.1</source>
-        <translation>cuteTube-QML - 0.4.1</translation>
+        <translation type="obsolete">cuteTube-QML - 0.4.1</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="36"/>
+        <source>cuteTube-QML - 0.4.2</source>
+        <translation>cuteTube-QML - 0.4.2</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="48"/>
@@ -211,22 +215,22 @@
 <context>
     <name>DownloadListDelegate</name>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="36"/>
+        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="36"/>
+        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="36"/>
+        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Failed</source>
         <translation>Fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="53"/>
+        <location filename="../DownloadListDelegate.qml" line="66"/>
         <source>Downloading</source>
         <translation>am Herrunterladen</translation>
     </message>
@@ -281,22 +285,22 @@
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="180"/>
+        <location filename="../HomeView.qml" line="177"/>
         <source>My Channel</source>
         <translation>Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="208"/>
+        <location filename="../HomeView.qml" line="202"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="236"/>
+        <location filename="../HomeView.qml" line="227"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="264"/>
+        <location filename="../HomeView.qml" line="252"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
@@ -541,167 +545,184 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="119"/>
+        <location filename="../SettingsDialog.qml" line="127"/>
         <source>Your saved searches have been cleared</source>
         <translation>Die gespeicherten Suchen wurden gelöscht</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="130"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Datenbankfehler. Konnte Konto nicht speichern</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="175"/>
+        <location filename="../SettingsDialog.qml" line="183"/>
         <source>Settings</source>
         <translation>Optionen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="209"/>
+        <location filename="../SettingsDialog.qml" line="217"/>
         <source>Playback quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="217"/>
+        <location filename="../SettingsDialog.qml" line="225"/>
         <source>Download quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="225"/>
+        <location filename="../SettingsDialog.qml" line="233"/>
         <source>Start downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="233"/>
+        <location filename="../SettingsDialog.qml" line="241"/>
         <source>Download location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="241"/>
+        <location filename="../SettingsDialog.qml" line="249"/>
         <source>Screen orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="249"/>
+        <location filename="../SettingsDialog.qml" line="257"/>
         <source>Media player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="257"/>
-        <location filename="../SettingsDialog.qml" line="393"/>
+        <location filename="../SettingsDialog.qml" line="118"/>
+        <location filename="../SettingsDialog.qml" line="274"/>
+        <location filename="../SettingsDialog.qml" line="428"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="92"/>
-        <location filename="../SettingsDialog.qml" line="283"/>
+        <location filename="../SettingsDialog.qml" line="97"/>
+        <location filename="../SettingsDialog.qml" line="300"/>
         <source>Playback Quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="95"/>
-        <location filename="../SettingsDialog.qml" line="301"/>
+        <location filename="../SettingsDialog.qml" line="100"/>
+        <location filename="../SettingsDialog.qml" line="318"/>
         <source>Download Quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="98"/>
-        <location filename="../SettingsDialog.qml" line="319"/>
+        <location filename="../SettingsDialog.qml" line="103"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
         <source>Start Downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="104"/>
-        <location filename="../SettingsDialog.qml" line="357"/>
+        <location filename="../SettingsDialog.qml" line="109"/>
+        <location filename="../SettingsDialog.qml" line="374"/>
         <source>Screen Orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="107"/>
-        <location filename="../SettingsDialog.qml" line="375"/>
+        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="392"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="15"/>
         <location filename="../SettingsDialog.qml" line="16"/>
+        <location filename="../SettingsDialog.qml" line="17"/>
         <source>Mobile</source>
         <translation>Mobil</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="15"/>
         <location filename="../SettingsDialog.qml" line="16"/>
+        <location filename="../SettingsDialog.qml" line="17"/>
         <source>High Quality</source>
         <translation>Hohe Qualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="34"/>
-        <location filename="../SettingsDialog.qml" line="58"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="36"/>
+        <location filename="../SettingsDialog.qml" line="62"/>
         <source>Automatically</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
         <source>Manually</source>
         <translation>Manuell</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
         <source>Automatic</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
         <source>Landscape</source>
         <translation>Querformat</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
         <source>Portrait</source>
         <translation>Hochformat</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="21"/>
+        <source>Light</source>
+        <translation>Licht</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="21"/>
+        <source>Dark</source>
+        <translation>Dunkel</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="22"/>
         <source>English</source>
         <translation>Englisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="22"/>
         <source>German</source>
         <translation>Deutsch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="33"/>
-        <location filename="../SettingsDialog.qml" line="59"/>
+        <location filename="../SettingsDialog.qml" line="35"/>
+        <location filename="../SettingsDialog.qml" line="63"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="62"/>
+        <location filename="../SettingsDialog.qml" line="66"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="64"/>
+        <location filename="../SettingsDialog.qml" line="69"/>
         <source>Your settings have been saved</source>
         <translation>Ihre Einstellungen wurden gespeichert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="69"/>
-        <location filename="../SettingsDialog.qml" line="101"/>
+        <location filename="../SettingsDialog.qml" line="74"/>
+        <location filename="../SettingsDialog.qml" line="106"/>
         <source>Download Path</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="72"/>
+        <location filename="../SettingsDialog.qml" line="77"/>
         <source>Download Location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="407"/>
+        <location filename="../SettingsDialog.qml" line="115"/>
+        <location filename="../SettingsDialog.qml" line="265"/>
+        <location filename="../SettingsDialog.qml" line="410"/>
+        <source>Theme</source>
+        <translation>Thema</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="442"/>
         <source>Clear saved searches</source>
         <translation>Lösche Suche</translation>
     </message>
@@ -709,7 +730,7 @@
 <context>
     <name>Sharing</name>
     <message>
-        <location filename="../../../sharing.cpp" line="75"/>
+        <location filename="../../../sharing.cpp" line="76"/>
         <source>Error - Server repsonse is: </source>
         <translation>Fehler - Serverantwort ist:</translation>
     </message>
@@ -895,6 +916,8 @@
         <translation>Ende</translation>
     </message>
     <message>
+        <location filename="../UploadProgressDialog.qml" line="95"/>
+        <location filename="../UploadProgressDialog.qml" line="101"/>
         <location filename="../UploadProgressDialog.qml" line="119"/>
         <source>Upload is in progress</source>
         <translation>Upload in Arbeit</translation>
@@ -1268,64 +1291,73 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="82"/>
+        <location filename="../main.qml" line="12"/>
+        <location filename="../main.qml" line="15"/>
+        <location filename="../main.qml" line="16"/>
+        <location filename="../main.qml" line="17"/>
+        <location filename="../main.qml" line="18"/>
+        <source>Dark</source>
+        <translation>Dunkel</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="91"/>
         <source>Video(s) added to download queue</source>
         <translation>Video(s) in Warteschlange eingefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="93"/>
+        <location filename="../main.qml" line="102"/>
         <source>Audio track(s) added to download queue</source>
         <translation>Audio Tracks in Warteschlange eingefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="114"/>
+        <location filename="../main.qml" line="123"/>
         <source>Video added to favourites</source>
         <translation>Video wurde zu Favoriten hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="115"/>
+        <location filename="../main.qml" line="124"/>
         <source>Video added to playlist</source>
         <translation>Video wurde zur Wiedergabeliste hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="122"/>
+        <location filename="../main.qml" line="131"/>
         <source>New playlist created</source>
         <translation>Neue Wiedergabeliste erstellt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="162"/>
+        <location filename="../main.qml" line="171"/>
         <source>Converting</source>
         <translation>Konvertiere</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="171"/>
+        <location filename="../main.qml" line="180"/>
         <source>Conversion of &apos;</source>
         <translation>Unterhaltung zwischen &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="171"/>
+        <location filename="../main.qml" line="180"/>
         <source>&apos; failed</source>
         <translation>&apos; gescheitert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="185"/>
-        <location filename="../main.qml" line="192"/>
-        <location filename="../main.qml" line="232"/>
+        <location filename="../main.qml" line="194"/>
+        <location filename="../main.qml" line="201"/>
+        <location filename="../main.qml" line="241"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="200"/>
+        <location filename="../main.qml" line="209"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="380"/>
+        <location filename="../main.qml" line="389"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="381"/>
+        <location filename="../main.qml" line="390"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
@@ -1333,67 +1365,67 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="18"/>
+        <location filename="../scripts/mainscripts.js" line="19"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="118"/>
+        <location filename="../scripts/mainscripts.js" line="119"/>
         <source>My Channel</source>
         <translation>Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="132"/>
+        <location filename="../scripts/mainscripts.js" line="133"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="171"/>
+        <location filename="../scripts/mainscripts.js" line="172"/>
         <source>My Playlists</source>
         <translation>Mein Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="181"/>
+        <location filename="../scripts/mainscripts.js" line="182"/>
         <source>My Subscriptions</source>
         <translation>Mein Abonnement</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="194"/>
+        <location filename="../scripts/mainscripts.js" line="195"/>
         <source>Video Info</source>
         <translation>Video Info</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="203"/>
+        <location filename="../scripts/mainscripts.js" line="204"/>
         <source>Video Playback</source>
         <translation>Video abspielen</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="213"/>
+        <location filename="../scripts/mainscripts.js" line="214"/>
         <source>Downloads</source>
         <translation>Downloads</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="221"/>
+        <location filename="../scripts/mainscripts.js" line="222"/>
         <source>date</source>
         <translation>datum</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="224"/>
+        <location filename="../scripts/mainscripts.js" line="225"/>
         <source>views</source>
         <translation>aufrufe</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="227"/>
+        <location filename="../scripts/mainscripts.js" line="228"/>
         <source>relevance</source>
         <translation>relevanz</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="230"/>
+        <location filename="../scripts/mainscripts.js" line="231"/>
         <source>rating</source>
         <translation>bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="237"/>
+        <location filename="../scripts/mainscripts.js" line="238"/>
         <source>Search </source>
         <translation>Suchlauf</translation>
     </message>
@@ -1428,6 +1460,11 @@
     </message>
     <message>
         <location filename="../scripts/settings.js" line="133"/>
+        <source>Dark</source>
+        <translation>Dunkel</translation>
+    </message>
+    <message>
+        <location filename="../scripts/settings.js" line="134"/>
         <source>English</source>
         <translation>Englisch</translation>
     </message>
